@@ -1,19 +1,20 @@
-use std::fs;
+use crate::{DdoResolver, Error};
+#[cfg(feature = "registrar")]
+use did_key::Document;
 use ipfs_api::IpfsClient;
 use serde::Deserialize;
-use web3::{Web3, contract::{
-        Contract,
-        Options
-    }, ethabi::Token, futures::StreamExt, transports::Http, types::Address};
+use std::fs;
 #[cfg(feature = "registrar")]
 use std::io::Cursor;
 #[cfg(feature = "registrar")]
-use web3::types::{U256, H160};
-#[cfg(feature = "registrar")]
-use did_key::Document;
-use crate::{
-    DdoResolver,
-    Error,
+use web3::types::{H160, U256};
+use web3::{
+    contract::{Contract, Options},
+    ethabi::Token,
+    futures::StreamExt,
+    transports::Http,
+    types::Address,
+    Web3,
 };
 
 pub const RINKEBY: &'static str = "./config/jolo_rinkeby.json";
@@ -29,17 +30,17 @@ pub struct JoloConfig {
 /// Instance of actual resolver
 /// Implements `DdoResolver` trait for synchronous resolution
 ///  and `async_resolve()` method for asynchronous resolution
-/// Can (and should) be used for cached/once instantiated 
+/// Can (and should) be used for cached/once instantiated
 ///  resolver for smoother performance.
 /// Available ONLY with `jolo` feature
 ///
 pub struct JoloResolver {
     contract: Contract<Http>,
     _w3: Web3<Http>,
-    client: IpfsClient
+    client: IpfsClient,
 }
 
-impl JoloResolver{
+impl JoloResolver {
     /// Generic constructor, which takes all required inputs separately
     /// #Parameters
     /// `provider_address` - endpoint for Ethereum network communications.
@@ -48,7 +49,11 @@ impl JoloResolver{
     /// `ipfs_endpoint` - entry point for IPFS resolution.
     ///     base URL only! ### Example: https://ipfs.jolocom.com:443
     ///
-    pub fn new(provider_address: &str, contract_address: &str, ipfs_endpoint: &str) -> Result<Self, Error> {
+    pub fn new(
+        provider_address: &str,
+        contract_address: &str,
+        ipfs_endpoint: &str,
+    ) -> Result<Self, Error> {
         let http = Http::new(provider_address)?;
         let _w3 = Web3::new(http);
         let c_address = Address::from_slice(&hex::decode(contract_address)?);
@@ -58,14 +63,14 @@ impl JoloResolver{
             contract: Contract::from_json(
                 _w3.eth(),
                 c_address,
-                include_bytes!("../resources/jolo_token.json")
+                include_bytes!("../resources/jolo_token.json"),
             )?,
             _w3,
-            client: ipfs_client
+            client: ipfs_client,
         })
     }
 
-    /// Constructor, which takes path to a JSON config file 
+    /// Constructor, which takes path to a JSON config file
     ///  which contains `JoloConfig` information and uses it
     ///  with generic constructor.
     ///
@@ -74,7 +79,7 @@ impl JoloResolver{
         Self::new(
             &config.provider_url,
             &config.contract_address,
-            &config.ipfs_endpoint
+            &config.ipfs_endpoint,
         )
     }
 
@@ -89,13 +94,10 @@ impl JoloResolver{
             return Err(Error::NotDidJolo);
         }
         let url_token = Token::FixedBytes(hex::decode(did_url.trim_start_matches("did:jolo:"))?);
-        let response: String = self.contract.query(
-            "getRecord",
-            (url_token,),
-            None,
-            Options::default(),
-            None
-        ).await?;
+        let response: String = self
+            .contract
+            .query("getRecord", (url_token,), None, Options::default(), None)
+            .await?;
         if response.is_empty() {
             Err(Error::DidResolutionFailed)
         } else {
@@ -113,7 +115,7 @@ impl JoloResolver{
         match ddo {
             Some(Ok(bytes)) => Ok(String::from_utf8(bytes.as_ref().to_vec())?),
             Some(Err(e)) => Err(Error::IpfsResponseError(e.to_string())),
-            _ => Err(Error::DidResolutionFailed)
+            _ => Err(Error::DidResolutionFailed),
         }
     }
 
@@ -122,7 +124,7 @@ impl JoloResolver{
         let cursor = Cursor::new(document);
         match self.client.add(cursor).await {
             Ok(res) => Ok(res.hash),
-            Err(e) => Err(Error::IpfsResponseError(e.to_string()))
+            Err(e) => Err(Error::IpfsResponseError(e.to_string())),
         }
     }
 
@@ -135,9 +137,9 @@ impl JoloResolver{
     ///
     pub async fn resolve_async(&self, did_url: &str) -> Result<did_key::Document, Error> {
         Ok(serde_json::from_str(
-            &self.get_ipfs_record(
-                &self.resolve_record(did_url.into()).await?
-            ).await?
+            &self
+                .get_ipfs_record(&self.resolve_record(did_url.into()).await?)
+                .await?,
         )?)
     }
 
@@ -170,14 +172,13 @@ impl JoloResolver{
             value: Some(U256::from_str_radix("0x00", 16).unwrap()),
             ..Options::default()
         };
-        match self.contract.call(
-        "setRecord",
-        (token, hash,),
-        from,
-        options
-        ).await {
+        match self
+            .contract
+            .call("setRecord", (token, hash), from, options)
+            .await
+        {
             Ok(_) => Ok(()),
-            Err(e) => Err(Error::W3ContractError(e))
+            Err(e) => Err(Error::W3ContractError(e)),
         }
     }
 }
@@ -185,14 +186,16 @@ impl JoloResolver{
 impl DdoResolver for JoloResolver {
     fn resolve(&self, did_url: &str) -> Result<did_key::Document, Error> {
         let rt = tokio::runtime::Runtime::new()?;
-        let hash = rt.block_on(self.resolve_record(did_url.into()))?; 
+        let hash = rt.block_on(self.resolve_record(did_url.into()))?;
         let ddo_from_ipfs = rt.block_on(self.get_ipfs_record(&hash))?;
         Ok(serde_json::from_str(&ddo_from_ipfs)?)
     }
 }
 
 fn read_config(path: &str) -> Result<JoloConfig, Error> {
-    Ok(serde_json::from_str::<JoloConfig>(&fs::read_to_string(path)?)?)
+    Ok(serde_json::from_str::<JoloConfig>(&fs::read_to_string(
+        path,
+    )?)?)
 }
 
 #[test]
@@ -220,7 +223,7 @@ async fn rinkeby_resolve() {
     let resolver = JoloResolver::new(
         &config.provider_url,
         &config.contract_address,
-        &config.ipfs_endpoint
+        &config.ipfs_endpoint,
     );
     assert!(resolver.is_ok());
     let response = resolver.unwrap().resolve_record(test_user_did.into()).await;
@@ -243,7 +246,9 @@ async fn ipfs_resolve() {
 #[test]
 fn jolo_doc_resolver() {
     let resolver = JoloResolver::new_from_cfg(RINKEBY).unwrap();
-    let doc = resolver.resolve("did:jolo:f334484858571199b681f6dfdd9ecd2f01df5b38f8379b3aaa89436c61fd1955").unwrap();
+    let doc = resolver
+        .resolve("did:jolo:f334484858571199b681f6dfdd9ecd2f01df5b38f8379b3aaa89436c61fd1955")
+        .unwrap();
     use crate::DdoParser;
     let key = doc.find_public_key_for_curve("ED");
     assert!(key.is_some());
@@ -253,15 +258,15 @@ fn jolo_doc_resolver() {
 #[cfg(feature = "registrar")]
 #[cfg(test)]
 mod registrar_tests {
-    use did_key::VerificationMethod;
     use super::JoloResolver;
+    use did_key::VerificationMethod;
 
     #[test]
     fn gas_conversion_test() {
         // panics if not succeeded
         let price = crate::jolo::U256::from_str_radix("0x4e3b29200", 16).unwrap();
         // panics if not succeeded
-        let limit = crate::jolo:: U256::from_str_radix("0x493e0", 16).unwrap();
+        let limit = crate::jolo::U256::from_str_radix("0x493e0", 16).unwrap();
         println!("price: {}, limit: {}", price, limit);
     }
 
@@ -269,22 +274,28 @@ mod registrar_tests {
     async fn registration_and_resolution_test() {
         let resolver = JoloResolver::new_from_cfg(super::RINKEBY).unwrap();
         let doc = did_key::Document {
-            context : "https://www.w3.org/ns/did/v1".into(),
+            context: "https://www.w3.org/ns/did/v1".into(),
             id: "f334484858571199b681f6dfdd9ecd2f01df5b38f8379b3aaa89436c61fd1955".into(),
             assertion_method: None,
             authentication: None,
             capability_delegation: None,
             capability_invocation: None,
             key_agreement: None,
-            verification_method: vec!(VerificationMethod::default())
+            verification_method: vec![VerificationMethod::default()],
         };
-        let result = resolver.register_async(
-            &doc, 
-            &hex::decode("c4b48901af7891d83ce83877e1f8fb4c81a94907").unwrap()
-            ).await;
-        if result.is_err() { println!("{:?}", result); }
+        let result = resolver
+            .register_async(
+                &doc,
+                &hex::decode("c4b48901af7891d83ce83877e1f8fb4c81a94907").unwrap(),
+            )
+            .await;
+        if result.is_err() {
+            println!("{:?}", result);
+        }
         assert!(result.is_ok());
-        let resolve_result = resolver.resolve_async(&format!("did:jolo:{}", doc.id)).await;
+        let resolve_result = resolver
+            .resolve_async(&format!("did:jolo:{}", doc.id))
+            .await;
         assert!(resolve_result.is_ok());
     }
 }
